@@ -34,7 +34,7 @@ if not os.path.isfile (os.path.join ('notify', 'all.py')):
               % (sys.argv[0], os.path.join ('notify', 'all.py')))
 
 
-print 'Building extension...'
+print ('Building extension...')
 
 # FIXME: Is that portable enough?
 if os.system ('python setup.py build') != 0:
