@@ -66,10 +66,11 @@ __all__       = ('Binding', 'WeakBinding', 'RaisingWeakBinding',
                  'CannotWeakReferenceError', 'GarbageCollectedError')
 
 
+import sys
 from types        import FunctionType, MethodType
 import weakref
 
-from notify.utils import is_callable, as_string, DummyReference
+from notify.utils import is_callable, DummyReference
 
 
 
@@ -326,6 +327,10 @@ class Binding (object):
 
         return True
 
+    if sys.version_info[0] >= 3:
+        __bool__ = __nonzero__
+        del __nonzero__
+
 
     im_self  = property (lambda self: self._get_object (),
                          doc = ("""
@@ -457,7 +462,7 @@ class WeakBinding (Binding):
     @see:  RaisingWeakBinding
     """
 
-    __slots__ = (as_string.__callback, as_string.__hash)
+    __slots__ = ('__callback', '__hash')
 
 
     def __init__(self, callable_object, arguments = (), callback = None):
@@ -589,7 +594,7 @@ class WeakBinding (Binding):
             if self:
                 self.__hash = super (WeakBinding, self).__hash__()
             else:
-                raise TypeError (("%s's object had been garbage-collected"
+                raise TypeError (("%s's object had been garbage-collected "
                                   "before first call to __hash__()")
                                  % self.__class__.__name__)
 
@@ -607,6 +612,10 @@ class WeakBinding (Binding):
 
         return self._object is not None
 
+    if sys.version_info[0] >= 3:
+        __bool__ = __nonzero__
+        del __nonzero__
+
 
 _NONE_REFERENCE = DummyReference (None)
 
