@@ -34,12 +34,13 @@ __all__       = ('AbstractCondition', 'AbstractStateTrackingCondition',
                  'Condition', 'PredicateCondition', 'WatcherCondition')
 
 
+import sys
 import weakref
 
 from notify.base   import AbstractValueObject
 from notify.gc     import AbstractGCProtector
 from notify.signal import CleanSignal
-from notify.utils  import is_callable, as_string, raise_not_implemented_exception, DummyReference
+from notify.utils  import execute, is_callable, raise_not_implemented_exception, DummyReference
 
 
 
@@ -105,6 +106,10 @@ class AbstractCondition (AbstractValueObject):
 
         return self.get ()
 
+    if sys.version_info[0] >= 3:
+        __bool__ = __nonzero__
+        del __nonzero__
+
 
     def __invert__(self):
         """
@@ -271,7 +276,7 @@ class AbstractStateTrackingCondition (AbstractCondition):
     internal ones inherit C{L{AbstractCondition}} directly instead.
     """
 
-    __slots__ = (as_string.__state)
+    __slots__ = ('__state')
 
 
     def __init__(self, initial_state):
@@ -343,18 +348,20 @@ class AbstractStateTrackingCondition (AbstractCondition):
 
         if 'getter' in options:
             if object is not None:
-                exec (('def __init__(self, %s):\n'
-                       '    cls.__init__(self, getter (%s))\n'
-                       '    %s = %s')
-                      % (object, object, AbstractValueObject._get_object (options), object)) \
-                      in filtered_options, functions
+                execute (('def __init__(self, %s):\n'
+                          '    cls.__init__(self, getter (%s))\n'
+                          '    %s = %s')
+                         % (object, object, AbstractValueObject._get_object (options), object),
+                         filtered_options, functions)
             else:
-                exec ('def __init__(self):\n'
-                      '    cls.__init__(self, getter (self))\n') in filtered_options, functions
+                execute ('def __init__(self):\n'
+                         '    cls.__init__(self, getter (self))\n',
+                         filtered_options, functions)
 
-            exec (('def resynchronize_with_backend (self):\n'
-                   '    self._set (getter (%s))')
-                  % AbstractValueObject._get_object (options)) in filtered_options, functions
+            execute (('def resynchronize_with_backend (self):\n'
+                      '    self._set (getter (%s))')
+                     % AbstractValueObject._get_object (options),
+                     filtered_options, functions)
 
         else:
             if 'setter' in options:
@@ -364,34 +371,35 @@ class AbstractStateTrackingCondition (AbstractCondition):
                 setter_statement = ''
 
             if object is not None:
-                exec (('def __init__(self, %s, initial_state):\n'
-                       '    cls.__init__(self, initial_state)\n'
-                       '    %s = %s\n'
-                       '    %s\n')
-                      % (object, AbstractValueObject._get_object (options), object,
-                         setter_statement)) \
-                      in filtered_options, functions
+                execute (('def __init__(self, %s, initial_state):\n'
+                          '    cls.__init__(self, initial_state)\n'
+                          '    %s = %s\n'
+                          '    %s\n')
+                         % (object, AbstractValueObject._get_object (options), object,
+                            setter_statement),
+                         filtered_options, functions)
             else:
-                exec (('def __init__(self, initial_state):\n'
-                       '    cls.__init__(self, initial_state)\n'
-                       '    %s\n')
-                      % setter_statement) \
-                      in filtered_options, functions
+                execute (('def __init__(self, initial_state):\n'
+                          '    cls.__init__(self, initial_state)\n'
+                          '    %s\n')
+                         % setter_statement,
+                         filtered_options, functions)
 
         if 'setter' in options:
-            exec (('def _set (self, value):\n'
-                   '    state = bool (value)\n'
-                   '    if self.get () != state:\n'
-                   '        setter (%s, state)\n'
-                   '        self._AbstractStateTrackingCondition__state = state\n'
-                   '        return self._value_changed (state)\n'
-                   '    else:\n'
-                   '        return False')
-                  % AbstractValueObject._get_object (options)) in filtered_options, functions
+            execute (('def _set (self, value):\n'
+                      '    state = bool (value)\n'
+                      '    if self.get () != state:\n'
+                      '        setter (%s, state)\n'
+                      '        self._AbstractStateTrackingCondition__state = state\n'
+                      '        return self._value_changed (state)\n'
+                      '    else:\n'
+                      '        return False')
+                     % AbstractValueObject._get_object (options),
+                     filtered_options, functions)
 
-            exec 'def set (self, value): return self._set (value)' in functions
+            execute ('def set (self, value): return self._set (value)', functions)
 
-        for function in functions.iteritems ():
+        for function in functions.items ():
             yield function
 
 
@@ -448,7 +456,7 @@ class PredicateCondition (AbstractStateTrackingCondition):
     conditions remember the way to evaluate their state.
     """
 
-    __slots__ = (as_string.__predicate)
+    __slots__ = ('__predicate')
 
 
     def __init__(self, predicate, initial_object):
@@ -525,7 +533,7 @@ class WatcherCondition (AbstractStateTrackingCondition):
     """
 
 
-    __slots__ = (as_string.__watched_condition)
+    __slots__ = ('__watched_condition')
 
 
     def __init__(self, condition_to_watch = None):
@@ -773,7 +781,7 @@ AbstractCondition.FALSE = _False ()
 class _Not (AbstractCondition):
 
     # We need to save our state, since `negated_condition' may be gc-collected.
-    __slots__ = (as_string.__state, as_string.__negated_condition)
+    __slots__ = ('__state', '__negated_condition')
 
 
     def __init__(self, negated_condition):
@@ -839,7 +847,7 @@ class _Not (AbstractCondition):
 
 class _Binary (AbstractCondition):
 
-    __slots__ = (as_string.__condition1, as_string.__condition2, '_term_state')
+    __slots__ = ('__condition1', '__condition2', '_term_state')
 
 
     def __init__(self, condition1, condition2):
@@ -983,7 +991,7 @@ class _Xor (_Binary):
 
 class _IfElse (AbstractCondition):
 
-    __slots__ = (as_string.__if, as_string.__then, as_string.__else, as_string.__term_state)
+    __slots__ = ('__if', '__then', '__else', '__term_state')
 
 
     __TERM_STATE_TO_SELF_STATE = (False, True, False, True, False, False, True, True)
