@@ -110,7 +110,7 @@ import weakref
 
 from notify.bind  import Binding, WeakBinding
 from notify.gc    import AbstractGCProtector
-from notify.utils import is_callable, as_string, raise_not_implemented_exception
+from notify.utils import is_callable, raise_not_implemented_exception
 
 try:
     import contextlib
@@ -356,6 +356,10 @@ class AbstractSignal (object):
 
         return self.has_handlers ()
 
+    if sys.version_info[0] >= 3:
+        __bool__ = __nonzero__
+        del __nonzero__
+
 
     def count_handlers (self):
         """
@@ -916,8 +920,7 @@ class Signal (AbstractSignal):
     interested in C{L{CleanSignal}}.
     """
 
-    __slots__ = ('_handlers', '_blocked_handlers',
-                 as_string.__accumulator, as_string.__emission_level)
+    __slots__ = ('_handlers', '_blocked_handlers', '__accumulator', '__emission_level')
 
 
     def __init__(self, accumulator = None):
@@ -1239,7 +1242,7 @@ class CleanSignal (Signal):
     Also, unlike plain C{Signal}, C{CleanSignal} allows to weakly reference itself.
     """
 
-    __slots__ = (as_string.__parent, '__weakref__')
+    __slots__ = ('__parent', '__weakref__')
 
 
     def __init__(self, parent = None, accumulator = None):
