@@ -37,24 +37,31 @@ Convert any attribute to its name as string.  Main use of this utility object is
 perform Python ‘private’ identifier mangling.  E.g. you can write::
 
     class MyClass (object):
-        __slots__ = (as_string.__x, as_string.__y)
-        def __init__(self):
-            self.__x, self__y = 0, 0
+        __slots__ = ('__x')
+        def get_x (self):
+            if hasattr (self, as_string.__x):
+                return self.__x
 
 Advantage is that you don’t have to do mangling ‘by hands’ and hence there is less chance
 for a typing error.  Furthermore, this code does not require changes if you change
 C{MyClass} name to anything else, whereas custom mangling does.
+
+However, usefulness of ‘as_string’ is still doubtful.  When I wrote it, I didn’t know one
+could just write ``__slots__ = ('__x')``, I thought it needed to be
+``__slots__ = ('_MyClass__x')``.  Imagine...
 """
 
 __docformat__ = 'epytext en'
 __all__       = ('is_callable', 'is_valid_identifier', 'mangle_identifier',
                  'as_string',
                  'raise_not_implemented_exception',
-                 'DummyReference')
+                 'execute',
+                 'DummyReference', 'StringType')
 
 
 import re
 import sys
+from keyword import iskeyword
 
 
 
@@ -78,8 +85,9 @@ def is_valid_identifier (identifier):
     @rtype:            C{bool}
     """
 
-    return (isinstance (identifier, basestring)
-            and re.match ('^[_a-zA-Z][_a-zA-Z0-9]*$', identifier) is not None)
+    return (isinstance (identifier, StringType)
+            and re.match ('^[_a-zA-Z][_a-zA-Z0-9]*$', identifier) is not None
+            and not iskeyword (identifier))
 
 
 def mangle_identifier (class_name, identifier):
@@ -222,6 +230,12 @@ def _find_declaration_classes (_class, function_name):
         return [_class]
 
 
+if sys.version_info[0] >= 3:
+    execute = eval ('exec')
+else:
+    from notify._2_x import execute
+
+
 
 class DummyReference (object):
 
@@ -234,7 +248,7 @@ class DummyReference (object):
     way.
     """
 
-    __slots__ = (as_string.__object)
+    __slots__ = ('__object')
 
 
     def __init__(self, object):
@@ -265,6 +279,12 @@ class DummyReference (object):
         return '<%s at 0x%x; to %s>' % (self.__class__.__name__, id (self), self.__object)
 
 
+if sys.version_info[0] >= 3:
+    StringType = str
+else:
+    StringType = basestring
+
+
 
 # Local variables:
 # mode: python
