@@ -33,7 +33,7 @@ if not os.path.isfile (os.path.join ('notify', 'all.py')):
               % (sys.argv[0], os.path.join ('notify', 'all.py')))
 
 
-print 'Building extension...'
+print ('Building extension...')
 
 # FIXME: Is that portable enough?
 if os.system ('python setup.py build_ext') != 0:
@@ -56,7 +56,7 @@ class AllTests (object):
         setattr (self, 'everything', lambda: everything)
 
 
-print '\nNote that most of the time is spent in gc.collect() calls, not in this package\n'
+print ('\nNote that most of the time is spent in gc.collect() calls, not in this package\n')
 
 unittest.main (AllTests (), 'everything')
 
